@@ -16,7 +16,7 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 #
-# $Id: CiscoIOS.pm,v 1.5 2007/07/13 13:41:50 evertonm Exp $
+# $Id: CiscoIOS.pm,v 1.6 2007/07/20 20:48:32 evertonm Exp $
 
 package fetchconfig::model::CiscoIOS; # fetchconfig/model/CiscoIOS.pm
 
@@ -59,9 +59,14 @@ sub chat_login {
     my ($self, $t, $dev_id, $dev_host, $dev_opt_tab) = @_;
     my $ok;
 
-    my ($prematch, $match) = $t->waitfor(Match => '/(Username:|Password:) $/');
+    my $login_prompt = '/(Username:|Password:) $/';
+
+    # chat_banner is used to allow temporary modification
+    # of timeout throught the 'banner_timeout' option
+
+    my ($prematch, $match) = $self->chat_banner($t, $dev_opt_tab, $login_prompt);
     if (!defined($prematch)) {
-	$self->log_error("could not find login prompt");
+	$self->log_error("could not find login prompt: $login_prompt");
 	return undef;
     }
 
